@@ -42,8 +42,8 @@ class CreditNote(Model):
         return request.send('get', request.uri_path("credit_notes",id), None, env, headers)
 
     @staticmethod
-    def pdf(id, env=None, headers=None):
-        return request.send('post', request.uri_path("credit_notes",id,"pdf"), None, env, headers)
+    def pdf(id, params=None, env=None, headers=None):
+        return request.send('post', request.uri_path("credit_notes",id,"pdf"), params, env, headers)
 
     @staticmethod
     def record_refund(id, params, env=None, headers=None):
