@@ -17,7 +17,7 @@ class Customer(Model):
       fields = ["type", "gateway", "gateway_account_id", "status", "reference_id"]
       pass
     class Balance(Model):
-      fields = ["promotional_credits", "excess_payments", "refundable_credits", "unbilled_charges", "balance_currency_code"]
+      fields = ["promotional_credits", "excess_payments", "refundable_credits", "unbilled_charges", "currency_code", "balance_currency_code"]
       pass
 
     fields = ["id", "first_name", "last_name", "email", "phone", "company", "vat_number", "auto_collection", \
@@ -54,6 +54,10 @@ class Customer(Model):
     def update_billing_info(id, params=None, env=None, headers=None):
         return request.send('post', request.uri_path("customers",id,"update_billing_info"), params, env, headers)
 
+    @staticmethod
+    def contacts_for_customer(id, params=None, env=None, headers=None):
+        return request.send('get', request.uri_path("customers",id,"contacts"), params, env, headers)
+
     @staticmethod
     def assign_payment_role(id, params, env=None, headers=None):
         return request.send('post', request.uri_path("customers",id,"assign_payment_role"), params, env, headers)
