@@ -48,9 +48,10 @@ class Invoice(Model):
     "price_type", "date", "due_date", "net_term_days", "currency_code", "total", "amount_paid", \
     "amount_adjusted", "write_off_amount", "credits_applied", "amount_due", "paid_at", "dunning_status", \
     "next_retry_at", "voided_at", "resource_version", "updated_at", "sub_total", "tax", "first_invoice", \
-    "has_advance_charges", "amount_to_collect", "round_off_amount", "line_items", "discounts", "line_item_discounts", \
-    "taxes", "line_item_taxes", "linked_payments", "applied_credits", "adjustment_credit_notes", \
-    "issued_credit_notes", "linked_orders", "notes", "shipping_address", "billing_address", "deleted"]
+    "has_advance_charges", "expected_payment_date", "amount_to_collect", "round_off_amount", "line_items", \
+    "discounts", "line_item_discounts", "taxes", "line_item_taxes", "linked_payments", "applied_credits", \
+    "adjustment_credit_notes", "issued_credit_notes", "linked_orders", "notes", "shipping_address", \
+    "billing_address", "deleted"]
 
 
     @staticmethod
@@ -98,8 +99,8 @@ class Invoice(Model):
         return request.send('get', request.uri_path("invoices",id), None, env, headers)
 
     @staticmethod
-    def pdf(id, env=None, headers=None):
-        return request.send('post', request.uri_path("invoices",id,"pdf"), None, env, headers)
+    def pdf(id, params=None, env=None, headers=None):
+        return request.send('post', request.uri_path("invoices",id,"pdf"), params, env, headers)
 
     @staticmethod
     def add_charge(id, params, env=None, headers=None):
